@@ -4,6 +4,8 @@ use Data::Object 'Class';
 
 extends 'Data::Object::Func::Array';
 
+our $VERSION = '0.94'; # VERSION
+
 # BUILD
 
 has arg1 => (
@@ -38,6 +40,8 @@ sub execute {
     my $value = $data->[$i];
 
     $found++ if $code->($value, @args);
+
+    last if $found > 1;
   }
 
   return $found == 1 ? 1 : 0;
