@@ -4,6 +4,8 @@ use Data::Object 'Class';
 
 extends 'Data::Object::Func::Array';
 
+our $VERSION = '0.94'; # VERSION
+
 # BUILD
 
 has arg1 => (
@@ -31,17 +33,17 @@ sub execute {
 
   my ($data, $code, @args) = $self->unpack;
 
-  my $retv = [[], []];
+  my $results = [[], []];
 
   for (my $i = 0; $i < @$data; $i++) {
     my $index = $i;
     my $value = $data->[$i];
     my $result = $code->($value, @args);
-    my $slot = $result ? $$retv[0] : $$retv[1];
+    my $slot = $result ? $$results[0] : $$results[1];
     push @$slot, $value;
   }
 
-  return $retv;
+  return $results;
 }
 
 sub mapping {
